import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ContentChildren, inject, ChangeDetectionStrategy, ViewEncapsulation, NgModule } from '@angular/core';
import { PrimeTemplate, SharedModule } from 'primeng/api';
import { UniqueComponentId } from 'primeng/utils';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { BaseComponent } from 'primeng/basecomponent';
import { BaseStyle } from 'primeng/base';

const theme = ({ dt }) => `
.p-steplist {
    position: relative;
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin: 0;
    padding: 0;
    list-style-type: none;
    overflow-x: auto;
}

.p-step {
    position: relative;
    display: flex;
    flex: 1 1 auto;
    align-items: center;
    gap: ${dt('stepper.step.gap')};
    padding: ${dt('stepper.step.padding')};
}

.p-step:last-of-type {
    flex: initial;
}

.p-step-header {
    border: 0 none;
    display: inline-flex;
    align-items: center;
    text-decoration: none;
    cursor: pointer;
    transition: background ${dt('stepper.transition.duration')}, color ${dt('stepper.transition.duration')}, border-color ${dt('stepper.transition.duration')}, outline-color ${dt('stepper.transition.duration')}, box-shadow ${dt('stepper.transition.duration')};
    border-radius: ${dt('stepper.step.header.border.radius')};
    outline-color: transparent;
    background: transparent;
    padding: ${dt('stepper.step.header.padding')};
    gap: ${dt('stepper.step.header.gap')};
}

.p-step-header:focus-visible {
    box-shadow: ${dt('stepper.step.header.focus.ring.shadow')};
    outline: ${dt('stepper.step.header.focus.ring.width')} ${dt('stepper.step.header.focus.ring.style')} ${dt('stepper.step.header.focus.ring.color')};
    outline-offset: ${dt('stepper.step.header.focus.ring.offset')};
}

.p-stepper.p-stepper-readonly .p-step {
    cursor: auto;
}

.p-step-title {
    display: block;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 100%;
    color: ${dt('stepper.step.title.color')};
    font-weight: ${dt('stepper.step.title.font.weight')};
    transition: background ${dt('stepper.transition.duration')}, color ${dt('stepper.transition.duration')}, border-color ${dt('stepper.transition.duration')}, box-shadow ${dt('stepper.transition.duration')}, outline-color ${dt('stepper.transition.duration')};
}

.p-step-number {
    display: flex;
    align-items: center;
    justify-content: center;
    color: ${dt('stepper.step.number.color')};
    border: 2px solid ${dt('stepper.step.number.border.color')};
    background: ${dt('stepper.step.number.background')};
    min-width: ${dt('stepper.step.number.size')};
    height: ${dt('stepper.step.number.size')};
    line-height: ${dt('stepper.step.number.size')};
    font-size: ${dt('stepper.step.number.font.size')};
    z-index: 1;
    border-radius: ${dt('stepper.step.number.border.radius')};
    position: relative;
    font-weight: ${dt('stepper.step.number.font.weight')};
}

.p-step-number::after {
    content: " ";
    position: absolute;
    width: 100%;
    height: 100%;
    border-radius: ${dt('stepper.step.number.border.radius')};
    box-shadow: ${dt('stepper.step.number.shadow')};
}

.p-step-active .p-step-header {
    cursor: default;
}

.p-step-active .p-step-number {
    background: ${dt('stepper.step.number.active.background')};
    border-color: ${dt('stepper.step.number.active.border.color')};
    color: ${dt('stepper.step.number.active.color')};
}

.p-step-active .p-step-title {
    color: ${dt('stepper.step.title.active.color')};
}

.p-step:not(.p-disabled):focus-visible {
    outline: ${dt('focus.ring.width')} ${dt('focus.ring.style')} ${dt('focus.ring.color')};
    outline-offset: ${dt('focus.ring.offset')};
}

.p-step:has(~ .p-step-active) .p-stepper-separator {
    background: ${dt('stepper.separator.active.background')};
}

.p-stepper-separator {
    flex: 1 1 0;
    background: ${dt('stepper.separator.background')};
    width: 100%;
    height: ${dt('stepper.separator.size')};
    transition: background ${dt('stepper.transition.duration')}, color ${dt('stepper.transition.duration')}, border-color ${dt('stepper.transition.duration')}, box-shadow ${dt('stepper.transition.duration')}, outline-color ${dt('stepper.transition.duration')};
}

.p-steppanels {
    padding: ${dt('stepper.steppanels.padding')};
}

.p-steppanel {
    background: ${dt('stepper.steppanel.background')};
    color: ${dt('stepper.steppanel.color')};
}

.p-stepper:has(.p-stepitem) {
    display: flex;
    flex-direction: column;
}

.p-stepitem {
    display: flex;
    flex-direction: column;
    flex: initial;
}

.p-stepitem.p-stepitem-active {
    flex: 1 1 auto;
}

.p-stepitem .p-step {
    flex: initial;
}

.p-stepitem .p-steppanel-content {
    width: 100%;
    padding: ${dt('stepper.steppanel.padding')};
}

.p-stepitem .p-steppanel {
    display: flex;
    flex: 1 1 auto;
}

.p-stepitem .p-stepper-separator {
    flex: 0 0 auto;
    width: ${dt('stepper.separator.size')};
    height: auto;
    margin: ${dt('stepper.separator.margin')};
    position: relative;
    left: calc(-1 * ${dt('stepper.separator.size')});
}

.p-stepitem:has(~ .p-stepitem-active) .p-stepper-separator {
    background: ${dt('stepper.separator.active.background')};
}

.p-stepitem:last-of-type .p-steppanel {
    padding-inline-start: ${dt('stepper.step.number.size')};
}

/* For PrimeNG */
.p-steppanel {
    overflow: hidden;
}

.p-stepppanel:not(.ng-animating) {
    overflow: inherit;
}
`;
const classes = {
    root: ({ props }) => [
        'p-stepper p-component',
        {
            'p-readonly': props.linear,
        },
    ],
    separator: 'p-stepper-separator',
};
class StepperStyle extends BaseStyle {
    name = 'stepper';
    theme = theme;
    classes = classes;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperStyle, deps: null, target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperStyle });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperStyle, decorators: [{
            type: Injectable
        }] });
/**
 *
 * Stepper is a component that streamlines a wizard-like workflow, organizing content into coherent steps and visually guiding users through a numbered progression in a multi-step process.
 *
 * [Live Demo](https://www.primeng.org/stepper/)
 *
 * @module stepperstyle
 *
 */
var StepperClasses;
(function (StepperClasses) {
    /**
     * Class name of the root element
     */
    StepperClasses["root"] = "p-stepper";
    /**
     * Class name of the separator element
     */
    StepperClasses["separator"] = "p-stepper-separator";
})(StepperClasses || (StepperClasses = {}));

class StepperHeader {
    id;
    template;
    stepperPanel;
    index;
    disabled;
    active;
    highlighted;
    getStepProp;
    ariaControls;
    onClick = new EventEmitter();
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperHeader, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.2", type: StepperHeader, selector: "p-stepperHeader, p-stepper-header", inputs: { id: "id", template: "template", stepperPanel: "stepperPanel", index: "index", disabled: "disabled", active: "active", highlighted: "highlighted", getStepProp: "getStepProp", ariaControls: "ariaControls" }, outputs: { onClick: "onClick" }, ngImport: i0, template: `
        <ng-container *ngIf="template; else buttonRef">
            <ng-container
                *ngTemplateOutlet="
                    template;
                    context: {
                        index: index,
                        active: active,
                        highlighted: highlighted,
                        class: 'p-stepper-action',
                        headerClass: 'p-stepper-action',
                        numberClass: 'p-stepper-number',
                        titleClass: 'p-stepper-title',
                        onClick: onClick,
                    }
                "
            ></ng-container>
        </ng-container>
        <ng-template #buttonRef>
            <p-button
                [id]="id"
                class="p-step-header"
                role="tab"
                [tabindex]="disabled ? -1 : undefined"
                [aria-controls]="ariaControls"
                (click)="onClick.emit($event, index)"
            >
                <span class="p-step-number">{{ index + 1 }}</span>
                <span class="p-step-title">{{ getStepProp }}</span>
            </p-button>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperHeader, decorators: [{
            type: Component,
            args: [{
                    selector: 'p-stepperHeader, p-stepper-header',
                    template: `
        <ng-container *ngIf="template; else buttonRef">
            <ng-container
                *ngTemplateOutlet="
                    template;
                    context: {
                        index: index,
                        active: active,
                        highlighted: highlighted,
                        class: 'p-stepper-action',
                        headerClass: 'p-stepper-action',
                        numberClass: 'p-stepper-number',
                        titleClass: 'p-stepper-title',
                        onClick: onClick,
                    }
                "
            ></ng-container>
        </ng-container>
        <ng-template #buttonRef>
            <p-button
                [id]="id"
                class="p-step-header"
                role="tab"
                [tabindex]="disabled ? -1 : undefined"
                [aria-controls]="ariaControls"
                (click)="onClick.emit($event, index)"
            >
                <span class="p-step-number">{{ index + 1 }}</span>
                <span class="p-step-title">{{ getStepProp }}</span>
            </p-button>
        </ng-template>
    `,
                }]
        }], propDecorators: { id: [{
                type: Input
            }], template: [{
                type: Input
            }], stepperPanel: [{
                type: Input
            }], index: [{
                type: Input
            }], disabled: [{
                type: Input
            }], active: [{
                type: Input
            }], highlighted: [{
                type: Input
            }], getStepProp: [{
                type: Input
            }], ariaControls: [{
                type: Input
            }], onClick: [{
                type: Output
            }] } });
class StepperSeparator {
    template;
    separatorClass;
    stepperPanel;
    index;
    active;
    highlighted;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperSeparator, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.2", type: StepperSeparator, selector: "p-stepperSeparator, p-stepper-separator", inputs: { template: "template", separatorClass: "separatorClass", stepperPanel: "stepperPanel", index: "index", active: "active", highlighted: "highlighted" }, host: { classAttribute: "p-stepper-separator" }, ngImport: i0, template: `
        <ng-container *ngIf="template; else span">
            <ng-container
                *ngTemplateOutlet="template; context: { index: index, active: active, highlighted: highlighted, class: separatorClass }"
            ></ng-container>
        </ng-container>
        <ng-template #span>
            <span [class]="separatorClass" aria-hidden="true"></span>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperSeparator, decorators: [{
            type: Component,
            args: [{
                    selector: 'p-stepperSeparator, p-stepper-separator',
                    template: `
        <ng-container *ngIf="template; else span">
            <ng-container
                *ngTemplateOutlet="template; context: { index: index, active: active, highlighted: highlighted, class: separatorClass }"
            ></ng-container>
        </ng-container>
        <ng-template #span>
            <span [class]="separatorClass" aria-hidden="true"></span>
        </ng-template>
    `,
                    host: {
                        class: 'p-stepper-separator',
                    },
                }]
        }], propDecorators: { template: [{
                type: Input
            }], separatorClass: [{
                type: Input
            }], stepperPanel: [{
                type: Input
            }], index: [{
                type: Input
            }], active: [{
                type: Input
            }], highlighted: [{
                type: Input
            }] } });
class StepperContent {
    id;
    orientation;
    template;
    ariaLabelledby;
    stepperPanel;
    index;
    active;
    highlighted;
    onClick = new EventEmitter();
    prevCallback = new EventEmitter();
    nextCallback = new EventEmitter();
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperContent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.2", type: StepperContent, selector: "p-stepperContent, p-stepper-content", inputs: { id: "id", orientation: "orientation", template: "template", ariaLabelledby: "ariaLabelledby", stepperPanel: "stepperPanel", index: "index", active: "active", highlighted: "highlighted" }, outputs: { onClick: "onClick", prevCallback: "prevCallback", nextCallback: "nextCallback" }, host: { properties: { "class.p-steppanel-content": "true", "class.p-element": "true", "class.p-toggleable-content": "orientation === 'vertical'" } }, ngImport: i0, template: ` <div
        [id]="id"
        role="tabpanel"
        data-pc-name="stepperpanel"
        [attr.data-pc-index]="index"
        [attr.data-p-active]="active"
        [attr.aria-labelledby]="ariaLabelledby"
    >
        <ng-container *ngIf="template">
            <ng-container
                *ngTemplateOutlet="
                    template;
                    context: {
                        index: index,
                        active: active,
                        highlighted: highlighted,
                        onClick: onClick,
                        prevCallback: prevCallback,
                        nextCallback: nextCallback,
                    }
                "
            ></ng-container>
        </ng-container>
        <ng-template *ngIf="!template">
            <ng-container *ngIf="stepperPanel">
                <ng-container *ngTemplateOutlet="stepperPanel"></ng-container>
            </ng-container>
        </ng-template>
    </div>`, isInline: true, dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperContent, decorators: [{
            type: Component,
            args: [{
                    selector: 'p-stepperContent, p-stepper-content',
                    template: ` <div
        [id]="id"
        role="tabpanel"
        data-pc-name="stepperpanel"
        [attr.data-pc-index]="index"
        [attr.data-p-active]="active"
        [attr.aria-labelledby]="ariaLabelledby"
    >
        <ng-container *ngIf="template">
            <ng-container
                *ngTemplateOutlet="
                    template;
                    context: {
                        index: index,
                        active: active,
                        highlighted: highlighted,
                        onClick: onClick,
                        prevCallback: prevCallback,
                        nextCallback: nextCallback,
                    }
                "
            ></ng-container>
        </ng-container>
        <ng-template *ngIf="!template">
            <ng-container *ngIf="stepperPanel">
                <ng-container *ngTemplateOutlet="stepperPanel"></ng-container>
            </ng-container>
        </ng-template>
    </div>`,
                    host: {
                        '[class.p-steppanel-content]': 'true',
                        '[class.p-element]': 'true',
                        '[class.p-toggleable-content]': "orientation === 'vertical'",
                    },
                }]
        }], propDecorators: { id: [{
                type: Input
            }], orientation: [{
                type: Input
            }], template: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], stepperPanel: [{
                type: Input
            }], index: [{
                type: Input
            }], active: [{
                type: Input
            }], highlighted: [{
                type: Input
            }], onClick: [{
                type: Output
            }], prevCallback: [{
                type: Output
            }], nextCallback: [{
                type: Output
            }] } });
class StepperPanel extends BaseComponent {
    header;
    templates;
    headerTemplate;
    startTemplate;
    contentTemplate;
    separatorTemplate;
    endTemplate;
    ngAfterContentInit() {
        this.templates.forEach((item) => {
            switch (item.getType()) {
                case 'header':
                    this.headerTemplate = item.template;
                    break;
                case 'content':
                    this.contentTemplate = item.template;
                    break;
                case 'separator':
                    this.separatorTemplate = item.template;
                    break;
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperPanel, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.2", type: StepperPanel, selector: "p-stepperPanel, p-stepper-panel", inputs: { header: "header" }, queries: [{ propertyName: "templates", predicate: PrimeTemplate }], usesInheritance: true, ngImport: i0, template: ` <ng-content></ng-content> `, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperPanel, decorators: [{
            type: Component,
            args: [{
                    selector: 'p-stepperPanel, p-stepper-panel',
                    template: ` <ng-content></ng-content> `,
                }]
        }], propDecorators: { header: [{
                type: Input
            }], templates: [{
                type: ContentChildren,
                args: [PrimeTemplate]
            }] } });
/**
 * The Stepper component displays a wizard-like workflow by guiding users through the multi-step progression.
 * @group Components
 */
class Stepper extends BaseComponent {
    /**
     * Active step index of stepper.
     * @group Props
     */
    activeStep = 0;
    /**
     * Orientation of the stepper.
     * @group Props
     */
    orientation = 'horizontal';
    /**
     * Whether the steps are clickable or not.
     * @group Props
     */
    linear = false;
    /**
     * Transition options of the animation.
     * @group Props
     */
    transitionOptions = '400ms cubic-bezier(0.86, 0, 0.07, 1)';
    stepperPanels;
    templates;
    onClick = new EventEmitter();
    /**
     * Emitted when the value changes.
     * @param {ActiveStepChangeEvent} event - custom change event.
     * @group Emits
     */
    activeStepChange = new EventEmitter();
    _componentStyle = inject(StepperStyle);
    headerTemplate;
    startTemplate;
    separatorTemplate;
    endTemplate;
    id = UniqueComponentId();
    panels;
    isStepActive(index) {
        return this.activeStep === index;
    }
    getStepProp(step) {
        if (step?.header) {
            return step.header;
        }
        if (step?.content) {
            return step.content;
        }
        return undefined;
    }
    getStepKey(step, index) {
        return this.getStepProp(step) || index;
    }
    getStepHeaderActionId(index) {
        return `${this.id}_${index}_header_action`;
    }
    getStepContentId(index) {
        return `${this.id}_${index}_content`;
    }
    updateActiveStep(event, index) {
        this.activeStep = index;
        this.activeStepChange.emit(this.activeStep);
    }
    onItemClick(event, index) {
        if (this.linear) {
            event.preventDefault();
            return;
        }
        if (index !== this.activeStep) {
            this.updateActiveStep(event, index);
        }
    }
    isItemDisabled(index) {
        return this.linear && !this.isStepActive(index);
    }
    prevCallback(event, index) {
        if (index !== 0) {
            this.updateActiveStep(event, index - 1);
        }
    }
    nextCallback(event, index) {
        if (index !== this.stepperPanels.length - 1) {
            this.updateActiveStep(event, index + 1);
        }
    }
    trackByFn(index) {
        return index;
    }
    ngAfterContentInit() {
        this.panels = this.stepperPanels.toArray();
        this.templates.forEach((item) => {
            switch (item.getType()) {
                case 'start':
                    this.startTemplate = item.template;
                    break;
                case 'end':
                    this.endTemplate = item.template;
                    break;
                default:
                    break;
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: Stepper, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.2", type: Stepper, selector: "p-stepper", inputs: { activeStep: "activeStep", orientation: "orientation", linear: "linear", transitionOptions: "transitionOptions" }, outputs: { onClick: "onClick", activeStepChange: "activeStepChange" }, host: { properties: { "class.p-stepper": "true", "class.p-component": "true", "class.p-stepper-vertical": "orientation === 'vertical'" } }, providers: [StepperStyle], queries: [{ propertyName: "stepperPanels", predicate: StepperPanel }, { propertyName: "templates", predicate: PrimeTemplate }], usesInheritance: true, ngImport: i0, template: `
        <ng-container *ngIf="startTemplate">
            <ng-container *ngTemplateOutlet="startTemplate"></ng-container>
        </ng-container>
        <ng-container *ngIf="orientation === 'horizontal'; else vertical">
            <ul class="p-steplist">
                <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                    <li
                        [key]="getStepKey(step, index)"
                        class="p-step"
                        [ngClass]="{
                            'p-step-active': isStepActive(index),
                            'p-disabled': isItemDisabled(index),
                        }"
                        [attr.aria-current]="isStepActive(index) ? 'step' : undefined"
                        role="presentation"
                        [data-pc-name]="stepperPanel"
                        [data-p-highlight]="isStepActive(index)"
                        [data-p-disabled]="isItemDisabled(index)"
                        [data-pc-index]="index"
                        [data-p-active]="isStepActive(index)"
                    >
                        <p-stepper-header
                            [id]="getStepHeaderActionId(index)"
                            [template]="step.headerTemplate"
                            [stepperPanel]="step"
                            [getStepProp]="getStepProp(step, 'header')"
                            [index]="index"
                            [disabled]="isItemDisabled(index)"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [aria-controls]="getStepContentId(index)"
                            (onClick)="onItemClick($event, index)"
                        ></p-stepper-header>

                        <ng-container *ngIf="index !== stepperPanels.length - 1">
                            <p-stepper-separator
                                [template]="step.separatorTemplate"
                                [separatorClass]="'p-stepper-separator'"
                                [stepperPanel]="step"
                                [index]="index"
                                [active]="isStepActive(index)"
                                [highlighted]="index < activeStep"
                            />
                        </ng-container>
                    </li>
                </ng-template>
            </ul>
            <div class="p-stepper-panels">
                <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                    <ng-container *ngIf="isStepActive(index)">
                        <p-stepper-content
                            [id]="getStepContentId(index)"
                            [template]="step.contentTemplate"
                            [orientation]="orientation"
                            [stepperPanel]="step"
                            [index]="index"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [ariaLabelledby]="getStepHeaderActionId(index)"
                            (onClick)="onItemClick($event, index)"
                            (nextCallback)="nextCallback($event, index)"
                            (prevCallback)="prevCallback($event, index)"
                        />
                    </ng-container>
                </ng-template>
            </div>
        </ng-container>
        <ng-template #vertical>
            <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                <div
                    [key]="getStepKey(step, index)"
                    class="p-stepitem"
                    [ngClass]="{
                        'p-stepitem-active': orientation === 'vertical' && isStepActive(index),
                    }"
                    [attr.aria-current]="isStepActive(index) ? 'step' : undefined"
                    [data-pc-name]="'stepperpanel'"
                    [data-p-highlight]="isStepActive(index)"
                    [data-p-disabled]="isItemDisabled(index)"
                    [data-pc-index]="index"
                    [data-p-active]="isStepActive(index)"
                >
                    <p-stepper-header
                        [id]="getStepHeaderActionId(index)"
                        [template]="step.headerTemplate"
                        [stepperPanel]="step"
                        [getStepProp]="getStepProp(step, 'header')"
                        [index]="index"
                        [disabled]="isItemDisabled(index)"
                        [active]="isStepActive(index)"
                        [highlighted]="index < activeStep"
                        [aria-controls]="getStepContentId(index)"
                        class="p-step"
                        [ngClass]="{ 'p-step-active': isStepActive(index) }"
                        (onClick)="onItemClick($event, index)"
                    ></p-stepper-header>

                    <div
                        class="p-steppanel"
                        [ngClass]="{ 'p-steppanel-active': isStepActive(index) }"
                        [@tabContent]="
                            isStepActive(index)
                                ? { value: 'visible', params: { transitionParams: transitionOptions } }
                                : { value: 'hidden', params: { transitionParams: transitionOptions } }
                        "
                    >
                        <ng-container *ngIf="index !== stepperPanels.length - 1">
                            <p-stepper-separator
                                [template]="step.separatorTemplate"
                                [separatorClass]="'p-stepper-separator'"
                                [stepperPanel]="step"
                                [index]="index"
                                [active]="isStepActive(index)"
                                [highlighted]="index < activeStep"
                            />
                        </ng-container>
                        <p-stepper-content
                            [id]="getStepContentId(index)"
                            [template]="step.contentTemplate"
                            [orientation]="orientation"
                            [stepperPanel]="step"
                            [index]="index"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [ariaLabelledby]="getStepHeaderActionId(index)"
                            (onClick)="onItemClick($event, index)"
                            (nextCallback)="nextCallback($event, index)"
                            (prevCallback)="prevCallback($event, index)"
                        />
                    </div>
                </div>
            </ng-template>
        </ng-template>
        <ng-container *ngIf="endTemplate">
            <ng-container *ngTemplateOutlet="endTemplate"></ng-container>
        </ng-container>
    `, isInline: true, dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: StepperContent, selector: "p-stepperContent, p-stepper-content", inputs: ["id", "orientation", "template", "ariaLabelledby", "stepperPanel", "index", "active", "highlighted"], outputs: ["onClick", "prevCallback", "nextCallback"] }, { kind: "component", type: StepperHeader, selector: "p-stepperHeader, p-stepper-header", inputs: ["id", "template", "stepperPanel", "index", "disabled", "active", "highlighted", "getStepProp", "ariaControls"], outputs: ["onClick"] }, { kind: "component", type: StepperSeparator, selector: "p-stepperSeparator, p-stepper-separator", inputs: ["template", "separatorClass", "stepperPanel", "index", "active", "highlighted"] }], animations: [
            trigger('tabContent', [
                state('hidden', style({
                    height: '0',
                    visibility: 'hidden',
                })),
                state('visible', style({
                    height: '*',
                    visibility: 'visible',
                })),
                transition('visible <=> hidden', [animate('250ms cubic-bezier(0.86, 0, 0.07, 1)')]),
                transition('void => *', animate(0)),
            ]),
        ], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: Stepper, decorators: [{
            type: Component,
            args: [{
                    selector: 'p-stepper',
                    template: `
        <ng-container *ngIf="startTemplate">
            <ng-container *ngTemplateOutlet="startTemplate"></ng-container>
        </ng-container>
        <ng-container *ngIf="orientation === 'horizontal'; else vertical">
            <ul class="p-steplist">
                <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                    <li
                        [key]="getStepKey(step, index)"
                        class="p-step"
                        [ngClass]="{
                            'p-step-active': isStepActive(index),
                            'p-disabled': isItemDisabled(index),
                        }"
                        [attr.aria-current]="isStepActive(index) ? 'step' : undefined"
                        role="presentation"
                        [data-pc-name]="stepperPanel"
                        [data-p-highlight]="isStepActive(index)"
                        [data-p-disabled]="isItemDisabled(index)"
                        [data-pc-index]="index"
                        [data-p-active]="isStepActive(index)"
                    >
                        <p-stepper-header
                            [id]="getStepHeaderActionId(index)"
                            [template]="step.headerTemplate"
                            [stepperPanel]="step"
                            [getStepProp]="getStepProp(step, 'header')"
                            [index]="index"
                            [disabled]="isItemDisabled(index)"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [aria-controls]="getStepContentId(index)"
                            (onClick)="onItemClick($event, index)"
                        ></p-stepper-header>

                        <ng-container *ngIf="index !== stepperPanels.length - 1">
                            <p-stepper-separator
                                [template]="step.separatorTemplate"
                                [separatorClass]="'p-stepper-separator'"
                                [stepperPanel]="step"
                                [index]="index"
                                [active]="isStepActive(index)"
                                [highlighted]="index < activeStep"
                            />
                        </ng-container>
                    </li>
                </ng-template>
            </ul>
            <div class="p-stepper-panels">
                <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                    <ng-container *ngIf="isStepActive(index)">
                        <p-stepper-content
                            [id]="getStepContentId(index)"
                            [template]="step.contentTemplate"
                            [orientation]="orientation"
                            [stepperPanel]="step"
                            [index]="index"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [ariaLabelledby]="getStepHeaderActionId(index)"
                            (onClick)="onItemClick($event, index)"
                            (nextCallback)="nextCallback($event, index)"
                            (prevCallback)="prevCallback($event, index)"
                        />
                    </ng-container>
                </ng-template>
            </div>
        </ng-container>
        <ng-template #vertical>
            <ng-template ngFor let-step [ngForOf]="panels" let-index="index" [ngForTrackBy]="trackByFn">
                <div
                    [key]="getStepKey(step, index)"
                    class="p-stepitem"
                    [ngClass]="{
                        'p-stepitem-active': orientation === 'vertical' && isStepActive(index),
                    }"
                    [attr.aria-current]="isStepActive(index) ? 'step' : undefined"
                    [data-pc-name]="'stepperpanel'"
                    [data-p-highlight]="isStepActive(index)"
                    [data-p-disabled]="isItemDisabled(index)"
                    [data-pc-index]="index"
                    [data-p-active]="isStepActive(index)"
                >
                    <p-stepper-header
                        [id]="getStepHeaderActionId(index)"
                        [template]="step.headerTemplate"
                        [stepperPanel]="step"
                        [getStepProp]="getStepProp(step, 'header')"
                        [index]="index"
                        [disabled]="isItemDisabled(index)"
                        [active]="isStepActive(index)"
                        [highlighted]="index < activeStep"
                        [aria-controls]="getStepContentId(index)"
                        class="p-step"
                        [ngClass]="{ 'p-step-active': isStepActive(index) }"
                        (onClick)="onItemClick($event, index)"
                    ></p-stepper-header>

                    <div
                        class="p-steppanel"
                        [ngClass]="{ 'p-steppanel-active': isStepActive(index) }"
                        [@tabContent]="
                            isStepActive(index)
                                ? { value: 'visible', params: { transitionParams: transitionOptions } }
                                : { value: 'hidden', params: { transitionParams: transitionOptions } }
                        "
                    >
                        <ng-container *ngIf="index !== stepperPanels.length - 1">
                            <p-stepper-separator
                                [template]="step.separatorTemplate"
                                [separatorClass]="'p-stepper-separator'"
                                [stepperPanel]="step"
                                [index]="index"
                                [active]="isStepActive(index)"
                                [highlighted]="index < activeStep"
                            />
                        </ng-container>
                        <p-stepper-content
                            [id]="getStepContentId(index)"
                            [template]="step.contentTemplate"
                            [orientation]="orientation"
                            [stepperPanel]="step"
                            [index]="index"
                            [active]="isStepActive(index)"
                            [highlighted]="index < activeStep"
                            [ariaLabelledby]="getStepHeaderActionId(index)"
                            (onClick)="onItemClick($event, index)"
                            (nextCallback)="nextCallback($event, index)"
                            (prevCallback)="prevCallback($event, index)"
                        />
                    </div>
                </div>
            </ng-template>
        </ng-template>
        <ng-container *ngIf="endTemplate">
            <ng-container *ngTemplateOutlet="endTemplate"></ng-container>
        </ng-container>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    providers: [StepperStyle],
                    host: {
                        '[class.p-stepper]': 'true',
                        '[class.p-component]': 'true',
                        '[class.p-stepper-vertical]': "orientation === 'vertical'",
                    },
                    animations: [
                        trigger('tabContent', [
                            state('hidden', style({
                                height: '0',
                                visibility: 'hidden',
                            })),
                            state('visible', style({
                                height: '*',
                                visibility: 'visible',
                            })),
                            transition('visible <=> hidden', [animate('250ms cubic-bezier(0.86, 0, 0.07, 1)')]),
                            transition('void => *', animate(0)),
                        ]),
                    ],
                }]
        }], propDecorators: { activeStep: [{
                type: Input
            }], orientation: [{
                type: Input
            }], linear: [{
                type: Input
            }], transitionOptions: [{
                type: Input
            }], stepperPanels: [{
                type: ContentChildren,
                args: [StepperPanel]
            }], templates: [{
                type: ContentChildren,
                args: [PrimeTemplate]
            }], onClick: [{
                type: Output
            }], activeStepChange: [{
                type: Output
            }] } });
class StepperModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.2", ngImport: i0, type: StepperModule, declarations: [Stepper, StepperPanel, StepperPanel, StepperContent, StepperHeader, StepperSeparator], imports: [CommonModule, SharedModule], exports: [Stepper, StepperPanel, StepperContent, StepperHeader, StepperSeparator, SharedModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperModule, imports: [CommonModule, SharedModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.2", ngImport: i0, type: StepperModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, SharedModule],
                    exports: [Stepper, StepperPanel, StepperContent, StepperHeader, StepperSeparator, SharedModule],
                    declarations: [Stepper, StepperPanel, StepperPanel, StepperContent, StepperHeader, StepperSeparator],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { Stepper, StepperContent, StepperHeader, StepperModule, StepperPanel, StepperSeparator };
//# sourceMappingURL=primeng-stepper.mjs.map
