import { AfterContentInit, AfterViewInit, ElementRef, EventEmitter, OnDestroy, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { PrimeTemplate } from 'primeng/api';
import { Nullable, VoidListener } from 'primeng/ts-helpers';
import { ButtonProps } from 'primeng/button';
import { BaseComponent } from 'primeng/basecomponent';
import { DrawerStyle } from './style/drawerstyle';
import * as i0 from "@angular/core";
import * as i1 from "@angular/common";
import * as i2 from "primeng/ripple";
import * as i3 from "primeng/api";
import * as i4 from "primeng/icons/times";
import * as i5 from "primeng/button";
/**
 * Sidebar is a panel component displayed as an overlay at the edges of the screen.
 * @group Components
 */
export declare class Sidebar extends BaseComponent implements AfterViewInit, AfterContentInit, OnDestroy {
    /**
     *  Target element to attach the dialog, valid values are "body" or a local ng-template variable of another element (note: use binding with brackets for template variables, e.g. [appendTo]="mydiv" for a div element having #mydiv as variable name).
     * @group Props
     */
    appendTo: HTMLElement | ElementRef | TemplateRef<any> | string | null | undefined | any;
    /**
     * Whether to block scrolling of the document when sidebar is active.
     * @group Props
     */
    blockScroll: boolean;
    /**
     * Inline style of the component.
     * @group Props
     */
    style: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Style class of the component.
     * @group Props
     */
    styleClass: string | undefined;
    /**
     * Aria label of the close icon.
     * @group Props
     */
    ariaCloseLabel: string | undefined;
    /**
     * Whether to automatically manage layering.
     * @group Props
     */
    autoZIndex: boolean;
    /**
     * Base zIndex value to use in layering.
     * @group Props
     */
    baseZIndex: number;
    /**
     * Whether an overlay mask is displayed behind the sidebar.
     * @group Props
     */
    modal: boolean;
    /**
     * Used to pass all properties of the ButtonProps to the Button component.
     * @group Props
     */
    closeButtonProps: ButtonProps;
    /**
     * Whether to dismiss sidebar on click of the mask.
     * @group Props
     */
    dismissible: boolean;
    /**
     * Whether to display the close icon.
     * @group Props
     */
    showCloseIcon: boolean;
    /**
     * Specifies if pressing escape key should hide the sidebar.
     * @group Props
     */
    closeOnEscape: boolean;
    /**
     * Transition options of the animation.
     * @group Props
     */
    transitionOptions: string;
    /**
     * Specifies the visibility of the dialog.
     * @group Props
     */
    get visible(): boolean;
    set visible(val: boolean);
    /**
     * Specifies the position of the sidebar, valid values are "left", "right", "bottom" and "top".
     * @group Props
     */
    get position(): string;
    set position(value: string);
    /**
     * Adds a close icon to the header to hide the dialog.
     * @group Props
     */
    get fullScreen(): boolean;
    set fullScreen(value: boolean);
    maskStyle: any;
    templates: QueryList<PrimeTemplate> | undefined;
    /**
     * Callback to invoke when dialog is shown.
     * @group Emits
     */
    onShow: EventEmitter<any>;
    /**
     * Callback to invoke when dialog is hidden.
     * @group Emits
     */
    onHide: EventEmitter<any>;
    /**
     * Callback to invoke when dialog visibility is changed.
     * @param {boolean} value - Visible value.
     * @group Emits
     */
    visibleChange: EventEmitter<boolean>;
    maskRef: ElementRef | undefined;
    containerViewChild: ElementRef | undefined;
    closeButtonViewChild: ElementRef | undefined;
    initialized: boolean | undefined;
    _visible: boolean | undefined;
    _position: string;
    _fullScreen: boolean;
    container: Nullable<HTMLDivElement>;
    transformOptions: any;
    mask: Nullable<HTMLDivElement>;
    documentEscapeListener: VoidListener;
    _componentStyle: DrawerStyle;
    /**
     * Header template.
     * @group Props
     */
    headerTemplate: TemplateRef<any> | undefined;
    _headerTemplate: Nullable<TemplateRef<any>>;
    /**
     * Footer template.
     * @group Props
     */
    footerTemplate: Nullable<TemplateRef<any>>;
    _footerTemplate: TemplateRef<any>;
    /**
     * Close icon template.
     * @group Props
     */
    closeIconTemplate: Nullable<TemplateRef<any>>;
    _closeIconTemplate: TemplateRef<any>;
    /**
     * Headless template.
     * @group Props
     */
    headlessTemplate: Nullable<TemplateRef<any>>;
    _headlessTemplate: TemplateRef<any>;
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterContentInit(): void;
    onKeyDown(event: KeyboardEvent): void;
    show(): void;
    hide(emit?: boolean): void;
    close(event: Event): void;
    maskClickListener(event: any): void;
    onAnimationStart(event: any): void;
    onAnimationEnd(event: any): void;
    appendContainer(): void;
    bindDocumentEscapeListener(): void;
    unbindDocumentEscapeListener(): void;
    unbindGlobalListeners(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<Sidebar, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<Sidebar, "p-sidebar", never, { "appendTo": { "alias": "appendTo"; "required": false; }; "blockScroll": { "alias": "blockScroll"; "required": false; }; "style": { "alias": "style"; "required": false; }; "styleClass": { "alias": "styleClass"; "required": false; }; "ariaCloseLabel": { "alias": "ariaCloseLabel"; "required": false; }; "autoZIndex": { "alias": "autoZIndex"; "required": false; }; "baseZIndex": { "alias": "baseZIndex"; "required": false; }; "modal": { "alias": "modal"; "required": false; }; "closeButtonProps": { "alias": "closeButtonProps"; "required": false; }; "dismissible": { "alias": "dismissible"; "required": false; }; "showCloseIcon": { "alias": "showCloseIcon"; "required": false; }; "closeOnEscape": { "alias": "closeOnEscape"; "required": false; }; "transitionOptions": { "alias": "transitionOptions"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "position": { "alias": "position"; "required": false; }; "fullScreen": { "alias": "fullScreen"; "required": false; }; "maskStyle": { "alias": "maskStyle"; "required": false; }; "headerTemplate": { "alias": "headerTemplate"; "required": false; }; "footerTemplate": { "alias": "footerTemplate"; "required": false; }; "closeIconTemplate": { "alias": "closeIconTemplate"; "required": false; }; "headlessTemplate": { "alias": "headlessTemplate"; "required": false; }; }, { "onShow": "onShow"; "onHide": "onHide"; "visibleChange": "visibleChange"; }, ["templates"], ["*"], false, never>;
    static ngAcceptInputType_blockScroll: unknown;
    static ngAcceptInputType_autoZIndex: unknown;
    static ngAcceptInputType_baseZIndex: unknown;
    static ngAcceptInputType_modal: unknown;
    static ngAcceptInputType_dismissible: unknown;
    static ngAcceptInputType_showCloseIcon: unknown;
    static ngAcceptInputType_closeOnEscape: unknown;
}
export declare class SidebarModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<SidebarModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<SidebarModule, [typeof Sidebar], [typeof i1.CommonModule, typeof i2.RippleModule, typeof i3.SharedModule, typeof i4.TimesIcon, typeof i5.ButtonModule], [typeof Sidebar, typeof i3.SharedModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<SidebarModule>;
}
